pub struct Symbol { /* private fields */ }Expand description
The Symbols in the ClangRuntime are constructed from the symbols in the process image except that there is one runtime Symbol for every private + public name of a process image symbol.
Implementations
Sourceimpl Symbol
impl Symbol
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Return true if this symbol is a function
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Return true if this is a publicly exported symbol (from the .dynsym)
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Return true if this is a private symbol (from .symtab)
Sourcepub fn contains_address(&self, addr: VAddr) -> bool
pub fn contains_address(&self, addr: VAddr) -> bool
Check whether this symbol contains the given address