Elf

Struct Elf 

pub struct Elf { /* private fields */ }
An Elf file in the process image is a container for Sections

Implementations

Source

impl Elf

pub fn path(&self) -> &Path

The path to the underlying ELF file, this Elf struct was generated from

pub fn builder() -> ElfBuilder

Create an ElfBuilder to create Elf files from scratch

Source

impl Elf

Accessor methods that handle the children of this process image element

pub fn cursor(&self) -> usize

Get the cursor of this process image element

pub fn set_cursor(&mut self, cursor: usize)

Set the cursor of this process image element

pub fn move_cursor_beyond_end(&mut self)

Move the cursor of this process image element to the end of its children list. This enables appending children.

pub fn move_cursor_forward(&mut self) -> bool

Increment the cursor of this process image element or return false if the cursor is already at the last child

pub fn move_cursor_backwards(&mut self) -> bool

Decrement the cursor of this process image element or return false if it’s already at the first child

pub fn section(&self, id: Id) -> Option<&Section>

Retrieve the child with the given ID of this process image element

pub fn num_sections(&self) -> usize

Get the number of children for this process image element

pub fn cursor_section(&self) -> Option<&Section>

Get the child at the current cursor position for this process image element

pub fn cursor_section_mut(&mut self) -> Option<&mut Section>

Get the child at the current cursor position for this process image element

pub fn insert_section(&mut self, child: Section) -> Id

Insert the given child into the list of children at the current cursor position for this process image element

pub fn delete_section(&mut self) -> Section

Delete the child at the current cursor position of this process image element and return it

pub fn iter_sections(&self) -> Iter<'_, Section>

Iterate over all children of this process image element independent of the current cursor position

pub fn iter_sections_mut(&mut self) -> IterMut<'_, Section>

Iterate over all children of this process image element independent of the current cursor position

pub fn section_mut(&mut self, id: Id) -> Option<&mut Section>

Retrieve the child with the given ID of this process image element