Section

Struct Section 

pub struct Section { /* private fields */ }
A Section is consecutive group of symbols that share the same permissions

Implementations

Source

impl Section

pub fn last_addr(&self) -> VAddr

The last virtual address occupied by this section (size - 1)

pub fn contains_address(&self, vaddr: VAddr) -> bool

Check whether this section contains the givem virtual address

pub fn size(&self) -> usize

The size of this section

pub fn perms(&self) -> Perms

The permissions of this section

pub fn vaddr(&self) -> VAddr

The virtual address of this section

pub fn set_size(&mut self, size: usize)

Change the size of this section

pub fn set_perms(&mut self, perms: Perms)

Change the permissions of this section

pub fn set_vaddr(&mut self, vaddr: VAddr)

Change the virtual address of this section

pub fn builder() -> SectionBuilder

Create a SectionBuilder that can build Sections from scratch

Source

impl Section

Accessor methods that handle the children of this process image element

pub fn cursor(&self) -> usize

Get the cursor of this process image element

pub fn set_cursor(&mut self, cursor: usize)

Set the cursor of this process image element

pub fn move_cursor_beyond_end(&mut self)

Move the cursor of this process image element to the end of its children list. This enables appending children.

pub fn move_cursor_forward(&mut self) -> bool

Increment the cursor of this process image element or return false if the cursor is already at the last child

pub fn move_cursor_backwards(&mut self) -> bool

Decrement the cursor of this process image element or return false if it’s already at the first child

pub fn symbol(&self, id: Id) -> Option<&Symbol>

Retrieve the child with the given ID of this process image element

pub fn num_symbols(&self) -> usize

Get the number of children for this process image element

pub fn cursor_symbol(&self) -> Option<&Symbol>

Get the child at the current cursor position for this process image element

pub fn cursor_symbol_mut(&mut self) -> Option<&mut Symbol>

Get the child at the current cursor position for this process image element

pub fn insert_symbol(&mut self, child: Symbol) -> Id

Insert the given child into the list of children at the current cursor position for this process image element

pub fn delete_symbol(&mut self) -> Symbol

Delete the child at the current cursor position of this process image element and return it

pub fn iter_symbols(&self) -> Iter<'_, Symbol>

Iterate over all children of this process image element independent of the current cursor position

pub fn iter_symbols_mut(&mut self) -> IterMut<'_, Symbol>

Iterate over all children of this process image element independent of the current cursor position

pub fn symbol_mut(&mut self, id: Id) -> Option<&mut Symbol>

Retrieve the child with the given ID of this process image element