pub struct Section { /* private fields */ }Expand description
A Section is consecutive group of symbols that share the same permissions
Implementations
Sourceimpl Section
impl Section
Sourcepub fn contains_address(&self, vaddr: VAddr) -> bool
pub fn contains_address(&self, vaddr: VAddr) -> bool
Check whether this section contains the givem virtual address
Sourcepub fn builder() -> SectionBuilder
pub fn builder() -> SectionBuilder
Create a SectionBuilder that can build Sections from scratch
Sourceimpl Section
Accessor methods that handle the children of this process image element
impl Section
Accessor methods that handle the children of this process image element
Sourcepub fn set_cursor(&mut self, cursor: usize)
pub fn set_cursor(&mut self, cursor: usize)
Set the cursor of this process image element
Sourcepub fn move_cursor_beyond_end(&mut self)
pub fn move_cursor_beyond_end(&mut self)
Move the cursor of this process image element to the end of its children list. This enables appending children.
Sourcepub fn move_cursor_forward(&mut self) -> bool
pub fn move_cursor_forward(&mut self) -> bool
Increment the cursor of this process image element or return false if the cursor
is already at the last child
Sourcepub fn move_cursor_backwards(&mut self) -> bool
pub fn move_cursor_backwards(&mut self) -> bool
Decrement the cursor of this process image element or return false if it’s already
at the first child
Sourcepub fn symbol(&self, id: Id) -> Option<&Symbol>
pub fn symbol(&self, id: Id) -> Option<&Symbol>
Retrieve the child with the given ID of this process image element
Sourcepub fn num_symbols(&self) -> usize
pub fn num_symbols(&self) -> usize
Get the number of children for this process image element
Sourcepub fn cursor_symbol(&self) -> Option<&Symbol>
pub fn cursor_symbol(&self) -> Option<&Symbol>
Get the child at the current cursor position for this process image element
Sourcepub fn cursor_symbol_mut(&mut self) -> Option<&mut Symbol>
pub fn cursor_symbol_mut(&mut self) -> Option<&mut Symbol>
Get the child at the current cursor position for this process image element
Sourcepub fn insert_symbol(&mut self, child: Symbol) -> Id
pub fn insert_symbol(&mut self, child: Symbol) -> Id
Insert the given child into the list of children at the current cursor position for this process image element
Sourcepub fn delete_symbol(&mut self) -> Symbol
pub fn delete_symbol(&mut self) -> Symbol
Delete the child at the current cursor position of this process image element and return it
Sourcepub fn iter_symbols(&self) -> Iter<'_, Symbol> ⓘ
pub fn iter_symbols(&self) -> Iter<'_, Symbol> ⓘ
Iterate over all children of this process image element independent of the current cursor position
Sourcepub fn iter_symbols_mut(&mut self) -> IterMut<'_, Symbol> ⓘ
pub fn iter_symbols_mut(&mut self) -> IterMut<'_, Symbol> ⓘ
Iterate over all children of this process image element independent of the current cursor position
Sourcepub fn symbol_mut(&mut self, id: Id) -> Option<&mut Symbol>
pub fn symbol_mut(&mut self, id: Id) -> Option<&mut Symbol>
Retrieve the child with the given ID of this process image element